<?xml version="1.0" encoding="utf-8"?>

<!--
Chrysalis Web Framework [http://chrysalis.sourceforge.net]
Copyright (c) 2002, 2003, 2004, Paul Strack

All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this
list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice,
this list of conditions and the following disclaimer in the documentation
and/or other materials provided with the distribution.

3. Neither the name of the copyright holder nor the names of its contributors
may be used to endorse or promote products derived from this software without
specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
                xmlns="http://www.w3.org/1999/xhtml">
  <xsl:output method="xml"/>

  <xsl:template match="taglib">
    <html>
      <head>
        <title><xsl:value-of select="shortname"/> library</title>
      </head>

      <body>
        <h2><code><xsl:value-of select="shortname"/></code>
        Tag Library Documentation</h2>
		
        <p><b>Library Version</b>: <xsl:value-of select="tlibversion"/><br/>
        <b>Library URI</b>: <code><xsl:value-of select="uri"/></code><br/>
        <b>JSP Required</b>: <xsl:value-of select="jspversion"/></p>
		
        <p><xsl:value-of select="info"/></p>
		
        <table width="100%" border="1" cellspacing="0" cellpadding="3">
          <tr><th colspan="2">Tag Summary</th></tr>
          <xsl:apply-templates select="tag" mode="toc">
            <xsl:sort select="name"/> 
          </xsl:apply-templates>
        </table>
		
        <h3>Library Description</h3>
        
        <p><xsl:apply-templates select="comment()"/></p>	
		
        <h2>Tag Details</h2>
		
        <xsl:apply-templates select="tag"/>
      </body>
  
     </html>
  </xsl:template>

  <xsl:template match="tag" mode="toc">
    <tr>
      <td width="1%">
        <xsl:element name="a">
          <xsl:attribute name="href">#<xsl:value-of select="name"/></xsl:attribute>
          <code>&lt;<xsl:value-of select="/taglib/shortname"/>:<xsl:value-of select="name"/>&gt;</code>
        </xsl:element>
      </td>
      <td><xsl:value-of select="info"/></td>
    </tr>
  </xsl:template>

  <xsl:template match="tag">
    <h3>
      <xsl:element name="a">
        <xsl:attribute name="name"><xsl:value-of select="name"/></xsl:attribute>
      </xsl:element>
      <code>&lt;<xsl:value-of select="/taglib/shortname"/>:<xsl:value-of select="name"/>&gt;</code> Tag
    </h3>

    <p><b>Tag Handler Class</b>: <code><xsl:value-of select="tagclass"/></code><br/>

    <xsl:if test="teiclass">
      <b>Tag Extra Info Class</b>: <code><xsl:value-of select="teiclass"/></code><br/>
    </xsl:if>

    <b>Tag Body Content</b>: <xsl:value-of select="bodycontent"/>
    
    <xsl:if test="attribute">
      <br/><b>Tag Attributes</b>: 
      <xsl:for-each select="attribute">
        <code><xsl:value-of select="name"/></code><xsl:if test="not(position()=last())">, </xsl:if>
      </xsl:for-each><br/>
    </xsl:if>
    </p>
    
    <p><xsl:apply-templates select="comment()"/></p>
	
    <xsl:if test="attribute">
      <h3>Tag Attributes</h3>
      <ul>
        <xsl:apply-templates select="attribute"/>
      </ul>
    </xsl:if>
  </xsl:template>

  <xsl:template match="attribute">
    <li>
      <code><xsl:value-of select="name"/></code>
      (<xsl:choose>
         <xsl:when test="required='true'">Required</xsl:when>
         <xsl:otherwise>Optional</xsl:otherwise>
       </xsl:choose>
       <xsl:if test="rtexprvalue='true'">, runtime expressions allowed</xsl:if>):
      <xsl:apply-templates select="comment()"/>
    </li>
  </xsl:template>

  <xsl:template match="comment()"> 
    <xsl:value-of select="." disable-output-escaping="yes"/>
  </xsl:template>
</xsl:stylesheet>